@@ -3,56 +3,36 @@ import asyncio
 from asyncio import sleep as aio_sleep
 from json import JSONDecodeError
 
+import httpcore
 import httpx
 
 from sanic import Sanic, server
 from sanic.response import text
-from sanic.testing import HOST, PORT, SanicTestClient
+from sanic.testing import HOST, SanicTestClient
 
 
 CONFIG_FOR_TESTS = {"KEEP_ALIVE_TIMEOUT": 2, "KEEP_ALIVE": True}
 
-old_conn = None
+PORT = 42101  # test_keep_alive_timeout_reuse doesn't work with random port
+
+from httpcore._async.base import ConnectionState
+from httpcore._async.connection import AsyncHTTPConnection
+from httpcore._types import Origin
 
 
-class ReusableSanicConnectionPool(
-    httpx.dispatch.connection_pool.ConnectionPool
-):
-    async def acquire_connection(self, origin, timeout):
-        global old_conn
-        connection = self.pop_connection(origin)
+class ReusableSanicConnectionPool(httpcore.AsyncConnectionPool):
+    last_reused_connection = None
 
-        if connection is None:
-            pool_timeout = None if timeout is None else timeout.pool_timeout
-
-            await self.max_connections.acquire(timeout=pool_timeout)
-            connection = httpx.dispatch.connection.HTTPConnection(
-                origin,
-                verify=self.verify,
-                cert=self.cert,
-                http2=self.http2,
-                backend=self.backend,
-                release_func=self.release_connection,
-                trust_env=self.trust_env,
-                uds=self.uds,
-            )
-
-        self.active_connections.add(connection)
-
-        if old_conn is not None:
-            if old_conn != connection:
-                raise RuntimeError(
-                    "We got a new connection, wanted the same one!"
-                )
-        old_conn = connection
-
-        return connection
+    async def _get_connection_from_pool(self, *args, **kwargs):
+        conn = await super()._get_connection_from_pool(*args, **kwargs)
+        self.__class__.last_reused_connection = conn
+        return conn
 
 
-class ResusableSanicSession(httpx.Client):
+class ResusableSanicSession(httpx.AsyncClient):
     def __init__(self, *args, **kwargs) -> None:
-        dispatch = ReusableSanicConnectionPool()
-        super().__init__(dispatch=dispatch, *args, **kwargs)
+        transport = ReusableSanicConnectionPool()
+        super().__init__(transport=transport, *args, **kwargs)
 
 
 class ReuseableSanicTestClient(SanicTestClient):
@@ -97,11 +77,9 @@ class ReuseableSanicTestClient(SanicTestClient):
         ):
             url = uri
         else:
-            uri = uri if uri.startswith("/") else "/{uri}".format(uri=uri)
+            uri = uri if uri.startswith("/") else f"/{uri}"
             scheme = "http"
-            url = "{scheme}://{host}:{port}{uri}".format(
-                scheme=scheme, host=HOST, port=PORT, uri=uri
-            )
+            url = f"{scheme}://{HOST}:{PORT}{uri}"
 
         @self.app.listener("after_server_start")
         async def _collect_response(loop):
@@ -134,7 +112,7 @@ class ReuseableSanicTestClient(SanicTestClient):
         self.app.listeners["after_server_start"].pop()
 
         if exceptions:
-            raise ValueError("Exception during request: {}".format(exceptions))
+            raise ValueError(f"Exception during request: {exceptions}")
 
         if gather_request:
             self.app.request_middleware.pop()
@@ -143,17 +121,13 @@ class ReuseableSanicTestClient(SanicTestClient):
                 return request, response
             except Exception:
                 raise ValueError(
-                    "Request and response object expected, got ({})".format(
-                        results
-                    )
+                    f"Request and response object expected, got ({results})"
                 )
         else:
             try:
                 return results[-1]
             except Exception:
-                raise ValueError(
-                    "Request object expected, got ({})".format(results)
-                )
+                raise ValueError(f"Request object expected, got ({results})")
 
     def kill_server(self):
         try:
@@ -163,7 +137,7 @@ class ReuseableSanicTestClient(SanicTestClient):
                 self._server = None
 
             if self._session:
-                self._loop.run_until_complete(self._session.close())
+                self._loop.run_until_complete(self._session.aclose())
                 self._session = None
 
         except Exception as e3:
@@ -182,7 +156,7 @@ class ReuseableSanicTestClient(SanicTestClient):
             self._session = self.get_new_session()
         try:
             response = await getattr(self._session, method.lower())(
-                url, verify=False, timeout=request_keepalive, *args, **kwargs
+                url, timeout=request_keepalive, *args, **kwargs
             )
         except NameError:
             raise Exception(response.status_code)
@@ -192,7 +166,7 @@ class ReuseableSanicTestClient(SanicTestClient):
         except (JSONDecodeError, UnicodeDecodeError):
             response.json = None
 
-        response.body = await response.read()
+        response.body = await response.aread()
         response.status = response.status_code
         response.content_type = response.headers.get("content-type")
 
@@ -244,6 +218,7 @@ def test_keep_alive_timeout_reuse():
         request, response = client.get("/1")
         assert response.status == 200
         assert response.text == "OK"
+        assert ReusableSanicConnectionPool.last_reused_connection
     finally:
         client.kill_server()
 
@@ -256,20 +231,15 @@ def test_keep_alive_client_timeout():
         asyncio.set_event_loop(loop)
         client = ReuseableSanicTestClient(keep_alive_app_client_timeout, loop)
         headers = {"Connection": "keep-alive"}
-        try:
-            request, response = client.get(
-                "/1", headers=headers, request_keepalive=1
-            )
-            assert response.status == 200
-            assert response.text == "OK"
-            loop.run_until_complete(aio_sleep(2))
-            exception = None
-            request, response = client.get("/1", request_keepalive=1)
-        except ValueError as e:
-            exception = e
-        assert exception is not None
-        assert isinstance(exception, ValueError)
-        assert "got a new connection" in exception.args[0]
+        request, response = client.get(
+            "/1", headers=headers, request_keepalive=1
+        )
+        assert response.status == 200
+        assert response.text == "OK"
+        loop.run_until_complete(aio_sleep(2))
+        exception = None
+        request, response = client.get("/1", request_keepalive=1)
+        assert ReusableSanicConnectionPool.last_reused_connection is None
     finally:
         client.kill_server()
 
@@ -284,22 +254,14 @@ def test_keep_alive_server_timeout():
         asyncio.set_event_loop(loop)
         client = ReuseableSanicTestClient(keep_alive_app_server_timeout, loop)
         headers = {"Connection": "keep-alive"}
-        try:
-            request, response = client.get(
-                "/1", headers=headers, request_keepalive=60
-            )
-            assert response.status == 200
-            assert response.text == "OK"
-            loop.run_until_complete(aio_sleep(3))
-            exception = None
-            request, response = client.get("/1", request_keepalive=60)
-        except ValueError as e:
-            exception = e
-        assert exception is not None
-        assert isinstance(exception, ValueError)
-        assert (
-            "Connection reset" in exception.args[0]
-            or "got a new connection" in exception.args[0]
+        request, response = client.get(
+            "/1", headers=headers, request_keepalive=60
         )
+        assert response.status == 200
+        assert response.text == "OK"
+        loop.run_until_complete(aio_sleep(3))
+        exception = None
+        request, response = client.get("/1", request_keepalive=60)
+        assert ReusableSanicConnectionPool.last_reused_connection is None
     finally:
         client.kill_server()
